/*!
 *****************************************************************************
 * @file: main.c
 * @brief: main file of PWM example project
   @version  V0.1
   @author   ADI
   @date     January 2019
   @par Revision History:
   - V0.1, January 2019: initial version. 
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "ADuCM410.h"
#include "WdtLib.h"
#include "common.h"
#include "GptLib.h"
#include "DioLib.h"
#include "PwmLib.h"
#include "ClkLib.h"

//---variable declaration
extern volatile int uiTime0;	
extern volatile int uiTime1;	
extern volatile int uiTime2;	
extern volatile int uiTime3;	
extern volatile int Error;



void delay(uint32_t t);
void timer0Test(void);
void timer1Test(void);
void timer2Test(void);
void PWMStart(void);

volatile int uiTime0 = 0;	              // Used for reading return value from PWMTime function
volatile int uiTime1 = 0;	              // Used for reading return value from PWMTime function
volatile int uiTime2 = 0;	              // Used for reading return value from PWMTime function
volatile int uiTime3 = 0;	              // Used for reading return value from PWMTime function
volatile int Error= 0;

int main (void)
{
    WdtGo(false);

    ClkSetup(&gClkSetup);

    SystemInit();
    INIT();
    SafetyWait();    
    
    PWMStart();
    NVIC_EnableIRQ(PWM_TRIP_IRQn);			     // Enable PWM Trip IRQ
    NVIC_EnableIRQ(PWM0_IRQn);			        // Enable pair 0 IRQ
    NVIC_EnableIRQ(PWM1_IRQn);			        // Enable pair 1 IRQ
    NVIC_EnableIRQ(PWM2_IRQn);			        // Enable pair 2 IRQ   
  //  NVIC_EnableIRQ(PWM3_IRQn);			        // Enable pair 3 IRQ
    /* Configure External Interrupt 0 */

  if (uiTime0 != 1)
		Error = 1;                               // Error with PWM pair 0 
   if (uiTime1 != 1)
		Error = 1;                               // Error with PWM pair 1
   if (uiTime2 != 1)
		Error = 1;                               // Error with PWM pair 2
   if (uiTime3 != 1)
		Error = 1;                               // Error with PWM pair 3	
    PwmGo(BITM_PWM_PWMCON0_PWMEN,0);           // Enable PWM outputs
    
    while(1)   
    {   
       DioTglPin(pADI_GPIO2,LED_PIN);
       delay(0x100000);
    }
  
}

void delay(uint32_t t)
{
   uint32_t i;
   for(i=0;i<t;i++);
}
void  PWMStart()
{
  //DioCfg(pADI_GPIO1,0xA0 );
  pADI_GPIO1->PWR = 0xFF;                      // Select 3V rail
  pADI_GPIO1->CON = 0xAAA0;                    // P1.2-P1.7 configured as PWM0 to PWM5
//  pADI_GPIO3->CON = 0x2A8;                     // P3.1 = PWM SYNC; P3.2= PWMTRIP, P3.3/4 = PWM6/7
  pADI_GPIO3->CON = 0x28;                     // P3.1 = PWM SYNC; P3.2= PWMTRIP

  PwmInit(PWMUCLK_2,BITM_PWM_PWMCON0_PWMIEN,
   BITM_PWM_PWMCON0_SYNC,
   0);                                         // Enable HCLK/2 as PWM clock and all PWM IRQ sources - except Trip
   //  BITM_PWM_PWMCON1_TRIP_EN);                  // Pull-up on P3.2_PWMTRIP needed if enabling trip function.
   uiTime0 = PwmTime(PWM0_1,200,150,40);       // PWM0 output for 75% high. PWM1 output 20% duty cycle.
   uiTime1 = PwmTime(PWM2_3,200,175,50);       // PWM2 output for 87.5% high. PWM3 output 25% dutycycle.
   uiTime2 = PwmTime(PWM4_5,100,50,49);        // PWM4 output for 50% high. PWM5 output 49.8% dutycycle.
  // uiTime3 = PwmTime(PWM6_7,1000,400,200);     // PWM6 output for 40% high. PWM7 output 20% dutycycle.
   PwmInvert(BITM_PWM_PWMCON0_PWM1INV,
             BITM_PWM_PWMCON0_PWM3INV,
             BITM_PWM_PWMCON0_PWM5INV, 0);

}

void PWMTrip_Int_Handler ()
{           
 PwmClrInt(BITM_PWM_PWMICLR_TRIP);             // Clear PWM trip IRQ
}
void PWM0_Int_Handler()
{
  PwmClrInt(BITM_PWM_PWMICLR_PWM0);
}
void PWM1_Int_Handler ()
{
 PwmClrInt(BITM_PWM_PWMICLR_PWM1);
}
void PWM2_Int_Handler()
{
  PwmClrInt(BITM_PWM_PWMICLR_PWM2);
}







